# memery
> Search over large image datasets with computer vision!


This file will become your README and also the index of your documentation.

## Install

`pip install memery`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```



